@@ -1,10 +1,10 @@
-#include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <dirent.h>
 
-#ifdef MACOSX
+// basically all UNIX-like OSes should use stat
+#ifndef WIN32
 #include <sys/stat.h>
 #endif
 
@@ -428,8 +428,10 @@ void scrollTextList (GLOBALDATA *global, ENVIRONMENT *env,
   draw_circlesBG (global, env->db, 0, 0, global->screenWidth, global->screenHeight, false);
   drawMenuBackground (global, env, BACKGROUND_BLANK, abs (tOffset), numItems);
   quickChange (global, env->db);
-  set_clip_rect (env->db, global->halfWidth - 300 + 1, 100 + 1,
-                 global->halfWidth + 300 - 1, global->screenHeight - 100 - 1);
+  //set_clip_rect (env->db, global->halfWidth - 300 + 1, 100 + 1,
+  //               global->halfWidth + 300 - 1, global->screenHeight - 100 - 1);
+  set_clip_rect(env->db, global->halfWidth - 300 + 1, global->menuBeginY + 1,
+                global->halfWidth + 300 - 1, global->menuEndY - 1);
   int scrollOffset = 0;
   flush_inputs ();
   if (! global->os_mouse) show_mouse (NULL);
@@ -441,8 +443,11 @@ void scrollTextList (GLOBALDATA *global, ENVIRONMENT *env,
 
       renderTextLines (global, env, lines, scrollOffset,
                        fnt, spacing );
-      blit (env->db, screen, global->halfWidth - 300, 100, global->halfWidth - 300, 100,
-            601, global->screenHeight - 199);
+      //blit (env->db, screen, global->halfWidth - 300, 100, global->halfWidth - 300, 100,
+      //      601, global->screenHeight - 199);
+      blit(env->db, screen, global->halfWidth - 300, global->menuBeginY,
+           global->halfWidth - 300, global->menuBeginY, 601, 
+           global->screenHeight - 2 * global->menuBeginY);
       LINUX_REST;
       if (moving)
       {
@@ -932,6 +937,11 @@ char ** Find_Bitmaps(GLOBALDATA *global, int *bitmaps_found)
         
      closedir(game_dir);
      *bitmaps_found = file_count;
+     if (file_count < 1)
+     {
+         free(my_list);
+         my_list = NULL;
+     }
      return my_list;
 }
 
