@@ -125,7 +125,7 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
             // advance clock
             if (global->Check_Time_Changed() )
                 AI_clock++;
-            if (AI_clock > MAX_AI_TIME)
+            if ( (AI_clock > MAX_AI_TIME) && (winner == -1) )
             {
                 // in over-time, kill all tanks
                 count = 0;
@@ -473,6 +473,7 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
 
         global->updateMenu = FALSE;
         my_player = my_tank->player;
+        // my_tank->reactivate_shield();
         control_result = my_player->controlTank();
         if (control_result == CONTROL_QUIT)
            done = TRUE;
@@ -489,11 +490,13 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
         if (fire)
         {
            env->stage = STAGE_FIRE;
+           if (my_tank)
+                my_tank->reactivate_shield();
            doLaunch(global, env);
            fire = FALSE;
            // screen_update = TRUE;
         }
-        else
+        // else
            // screen_update = FALSE;
 
         screen_update = FALSE;
@@ -570,7 +573,10 @@ int game (GLOBALDATA *global, ENVIRONMENT *env)
     for (count = 0; count < global->numPlayers; count++)
     {
        if (global->players[count]->tank)
+       {
+          global->players[count]->Reclaim_Shield();
           delete global->players[count]->tank;
+       }
     }
 
     return done;
