@@ -47,6 +47,9 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
   temp_screenHeight = screenHeight;
   halfWidth = screenWidth / 2;
   halfHeight = screenHeight / 2;
+  menuBeginY = (screenHeight - 400) / 2;
+  if (menuBeginY < 0) menuBeginY = 0;
+  menuEndY = screenHeight - menuBeginY;
   frames_per_second = FRAMES_PER_SECOND;
   numPermanentPlayers = 10;
   violent_death = FALSE;
@@ -247,73 +250,7 @@ This function loads global settings from a text
 file. The function returns TRUE on success and FALSE if
 any erors are encountered.
 -- Jesse
-
-Changed to binary mode, being the counterpart to loadFromFile()
-The original methid is below.
--- Sven
 */
-int GLOBALDATA::loadFromFile(ifstream &ifsFile)
-{
-  char chArea[NAME_LENGTH] = "";
-  double dData = 0.0;
-  bool bResult = true;
-  bool bIsFinished = false;
-  bool bIsData = false;
-
-  double sound_bookmark = 1.0;
-  if (! sound)
-    sound_bookmark = sound;
-
-  while (!bIsFinished && (bResult = popData(chArea, bIsData, ifsFile)))
-    {
-      if (!bIsData && !strcmp(chArea, FILEPART_ENDSECT))      bIsFinished  = true;
-      else if (!strcmp(chArea, "Dither Gradient   ")) bResult = popData(ditherGradients,        ifsFile);
-      else if (!strcmp(chArea, "Detail Landscape  ")) bResult = popData(detailedLandscape,      ifsFile);
-      else if (!strcmp(chArea, "Detail Sky        ")) bResult = popData(detailedSky,            ifsFile);
-      else if (!strcmp(chArea, "Interest          ")) bResult = popData(interest,               ifsFile);
-      else if (!strcmp(chArea, "Score Round Win   ")) bResult = popData(scoreRoundWinBonus,     ifsFile);
-      else if (!strcmp(chArea, "Score Unit Hit    ")) bResult = popData(scoreHitUnit,           ifsFile);
-      else if (!strcmp(chArea, "Score Unit Destroy")) bResult = popData(scoreUnitDestroyBonus,  ifsFile);
-      else if (!strcmp(chArea, "Score Self Destroy")) bResult = popData(scoreUnitSelfDestroy,   ifsFile);
-      else if (!strcmp(chArea, "Sell Ratio        ")) bResult = popData(sellpercent,            ifsFile);
-      else if (!strcmp(chArea, "Start Money       ")) bResult = popData(startmoney,             ifsFile);
-      else if (!strcmp(chArea, "Turn Type         ")) bResult = popData(turntype,               ifsFile);
-      else if (!strcmp(chArea, "Skip Computer Play")) bResult = popData(skipComputerPlay,       ifsFile);
-      else if (!strcmp(chArea, "Sound             ")) bResult = popData(sound,                  ifsFile);
-      else if (!strcmp(chArea, "Screen Width      ")) bResult = popData(screenWidth,            ifsFile);
-      else if (!strcmp(chArea, "Screen Height     ")) bResult = popData(screenHeight,           ifsFile);
-      else if (!strcmp(chArea, "OS Mouse          ")) bResult = popData(os_mouse,               ifsFile);
-      else if (!strcmp(chArea, "Permanent Players ")) bResult = popData(numPermanentPlayers,    ifsFile);
-      else if (!strcmp(chArea, "Language          ")) bResult = popData(language,               ifsFile);
-      else if (!strcmp(chArea, "Color Theme       ")) bResult = popData(colour_theme,           ifsFile);
-      else if (!strcmp(chArea, "Frames Per Second ")) bResult = popData(frames_per_second,      ifsFile);
-      else if (!strcmp(chArea, "Violent Death     ")) bResult = popData(violent_death,          ifsFile);
-      else if (!strcmp(chArea, "Max Fire Time     ")) bResult = popData(max_fire_time,          ifsFile);
-      else if (!strcmp(chArea, "Divide Money      ")) bResult = popData(divide_money,           ifsFile);
-      else if (!strcmp(chArea, "Check Updates     ")) bResult = popData(check_for_updates,      ifsFile);
-      else if (!strcmp(chArea, "Networking        ")) bResult = popData(enable_network,         ifsFile);
-      else if (!strcmp(chArea, "Listen Port       ")) bResult = popData(listen_port,            ifsFile);
-      else if (!strcmp(chArea, "Sound Driver      ")) bResult = popData(sound_driver,           ifsFile);
-      else if (!bIsFinished && bIsData)
-        bResult = popData(dData, ifsFile); // Something we do not know (any more/yet), so dump it!
-    }
-
-  if (! sound_bookmark)
-    sound = sound_bookmark;
-
-  if (width_override)
-    screenWidth = width_override;
-  if (height_override)
-    screenHeight = height_override;
-
-  halfWidth = screenWidth / 2;
-  halfHeight = screenHeight / 2;
-
-  if (skipComputerPlay > SKIP_HUMANS_DEAD)
-    skipComputerPlay = SKIP_HUMANS_DEAD;
-
-  return(bResult);
-}
 
 int GLOBALDATA::loadFromFile_Text (FILE *file)
 {
@@ -449,6 +386,10 @@ int GLOBALDATA::loadFromFile_Text (FILE *file)
   halfWidth = screenWidth / 2;
   halfHeight = screenHeight / 2;
 
+  menuBeginY = (screenHeight - 400) / 2;
+  if (menuBeginY < 0) menuBeginY = 0;
+  menuEndY = screenHeight - menuBeginY;
+
   if (skipComputerPlay > SKIP_HUMANS_DEAD)
     skipComputerPlay = SKIP_HUMANS_DEAD;
 
@@ -1126,7 +1067,7 @@ void GLOBALDATA::Credit_Winners(int winner)
    int team_members = 0;
    int index;
 
-   if (winner <= 0)    // no winner
+   if (winner < 0)    // no winner
       return;
 
    if (winner == JEDI_WIN)
